@@ -734,9 +734,12 @@ Gen::TypesVisitor::visitSequence(const SequencePtr& p)
         out << nl << "var v = " << fixIdent(name) << "(repeating: nil, count: sz)";
         out << nl << "for i in 0 ..< sz";
         out << sb;
-        out << nl << "let p = UnsafeMutablePointer<" << typeToString(p->type(), p) << ">(&v[i])";
+        out << nl << "try Swift.withUnsafeMutablePointer(to: &v[i])";
+        out << sb;
+        out << " p in";
         writeMarshalUnmarshalCode(out, type, p, "p.pointee", false);
         out << eb;
+        out << eb;
     }
     else
     {
@@ -885,15 +888,20 @@ Gen::TypesVisitor::visitDictionary(const DictionaryPtr& p)
         string keyParam = "let key: " + keyType;
         writeMarshalUnmarshalCode(out, p->keyType(), p, keyParam, false);
         out << nl << "v[key] = nil as " << valueType;
+        out << nl << "Swift.withUnsafeMutablePointer(to: &v[key, default:nil])";
+        out << sb;
         out << nl << "e.values[i] = Ice.DictEntry<" << keyType << ", " << valueType << ">("
             << "key: key, "
-            << "value: UnsafeMutablePointer<" << valueType << ">(&v[key, default:nil]))";
+            << "value: $0)";
+        out << eb;
         writeMarshalUnmarshalCode(out, p->valueType(), p, "e.values[i].value.pointee", false);
         out << eb;
 
         out << nl << "for i in 0..<sz" << sb;
-        out << nl << "e.values[i].value = Swift.UnsafeMutablePointer<" << valueType
-            << ">(&v[e.values[i].key, default:nil])";
+        out << nl << "Swift.withUnsafeMutablePointer(to: &v[e.values[i].key, default:nil])";
+        out << sb;
+        out << nl << "e.values[i].value = $0";
+        out << eb;
         out << eb;
     }
     else
