@@ -240,6 +240,27 @@ allTests(const Ice::CommunicatorPtr& communicator, const Ice::CommunicatorPtr& c
     testRetryCount(4);
     cout << "ok" << endl;
 
+    if(retry1->ice_getCachedConnection())
+    {
+        cout << "testing non-idempotent operation with bi-dir proxy... " << flush;
+        try
+        {
+            retry1->ice_fixed(retry1->ice_getCachedConnection())->opIdempotent(4);
+        }
+        catch(const Ice::Exception&)
+        {
+        }
+        testInvocationCount(1);
+        testFailureCount(1);
+        testRetryCount(0);
+        test(retry1->opIdempotent(4) == 4);
+        testInvocationCount(1);
+        testFailureCount(0);
+        // It suceeded after 3 retry because of the failed opIdempotent on the fixed proxy above
+        testRetryCount(3);
+        cout << "ok" << endl;
+    }
+
     cout << "testing non-idempotent operation... " << flush;
     try
     {
@@ -339,10 +360,10 @@ allTests(const Ice::CommunicatorPtr& communicator, const Ice::CommunicatorPtr& c
             // The timeout might occur on connection establishment or because of the sleep. What's
             // important here is to make sure there are 4 retries and that no calls succeed to
             // ensure retries with the old connection timeout semantics work.
-            RetryPrxPtr retryWithTimeout = retry1->ice_invocationTimeout(-2)->ice_timeout(200);
+            RetryPrxPtr retryWithTimeout = retry1->ice_invocationTimeout(-2)->ice_timeout(100);
             try
             {
-                retryWithTimeout->sleep(500);
+                retryWithTimeout->sleep(1000);
                 test(false);
             }
             catch(const Ice::TimeoutException&)
