@@ -167,6 +167,27 @@ namespace Ice
                 Instrumentation.testRetryCount(4);
                 output.WriteLine("ok");
 
+                if(retry1.ice_getCachedConnection() != null)
+                {
+                    output.Write("testing non-idempotent operation with bi-dir proxy... ");
+                    try
+                    {
+                        ((Test.RetryPrx)retry1.ice_fixed(retry1.ice_getCachedConnection())).opIdempotent(4);
+                    }
+                    catch(Ice.Exception)
+                    {
+                    }
+                    Instrumentation.testInvocationCount(1);
+                    Instrumentation.testFailureCount(1);
+                    Instrumentation.testRetryCount(0);
+                    test(retry1.opIdempotent(4) == 4);
+                    Instrumentation.testInvocationCount(1);
+                    Instrumentation.testFailureCount(0);
+                    // It suceeded after 3 retry because of the failed opIdempotent on the fixed proxy above
+                    Instrumentation.testRetryCount(3);
+                    output.WriteLine("ok");
+                }
+
                 output.Write("testing non-idempotent operation... ");
                 try
                 {
@@ -258,10 +279,10 @@ namespace Ice
                         // important here is to make sure there are 4 retries and that no calls succeed to
                         // ensure retries with the old connection timeout semantics work.
                         Test.RetryPrx retryWithTimeout =
-                            (Test.RetryPrx)retry1.ice_invocationTimeout(-2).ice_timeout(200);
+                            (Test.RetryPrx)retry1.ice_invocationTimeout(-2).ice_timeout(100);
                         try
                         {
-                            retryWithTimeout.sleep(500);
+                            retryWithTimeout.sleep(1000);
                             test(false);
                         }
                         catch(Ice.TimeoutException)
