@@ -237,10 +237,10 @@ public class AllTests
                 long now = com.zeroc.IceInternal.Time.currentMonotonicTimeMillis();
                 try
                 {
-                    wait(2000);
-                    if(com.zeroc.IceInternal.Time.currentMonotonicTimeMillis() - now > 2000)
+                    wait(30000);
+                    if(com.zeroc.IceInternal.Time.currentMonotonicTimeMillis() - now > 30000)
                     {
-                        test(false); // Waited for more than 2s for close, something's wrong.
+                        test(false); // Waited for more than 30s for close, something's wrong.
                     }
                 }
                 catch(java.lang.InterruptedException ex)
@@ -370,8 +370,7 @@ public class AllTests
 
         public void runTestCase(RemoteObjectAdapterPrx adapter, TestIntfPrx proxy)
         {
-            // No close on invocation, the call should succeed this
-            // time.
+            // No close on invocation, the call should succeed this time.
             proxy.sleep(3);
 
             synchronized(this)
@@ -392,16 +391,7 @@ public class AllTests
 
         public void runTestCase(RemoteObjectAdapterPrx adapter, TestIntfPrx proxy)
         {
-            try
-            {
-                Thread.sleep(3000); // Idle for 3 seconds
-            }
-            catch(java.lang.InterruptedException ex)
-            {
-            }
-
             waitForClosed();
-
             synchronized(this)
             {
                 test(_heartbeat == 0);
@@ -440,7 +430,7 @@ public class AllTests
         public CloseOnIdleAndInvocationTest(TestHelper helper, RemoteCommunicatorPrx com, java.io.PrintWriter out)
         {
             super(helper, "close on idle and invocation", com, out);
-            setClientACM(1, 3, 0); // Only close on idle and invocation
+            setClientACM(3, 3, 0); // Only close on idle and invocation
         }
 
         public void runTestCase(RemoteObjectAdapterPrx adapter, TestIntfPrx proxy)
@@ -453,7 +443,7 @@ public class AllTests
             adapter.hold();
             try
             {
-                Thread.sleep(3000); // Idle for 3 seconds
+                Thread.sleep(5000); // Idle for 5 seconds
             }
             catch(java.lang.InterruptedException ex)
             {
@@ -466,14 +456,6 @@ public class AllTests
             }
 
             adapter.activate();
-            try
-            {
-                Thread.sleep(1000);
-            }
-            catch(java.lang.InterruptedException ex)
-            {
-            }
-
             waitForClosed();
         }
     }
@@ -489,13 +471,6 @@ public class AllTests
         public void runTestCase(RemoteObjectAdapterPrx adapter, TestIntfPrx proxy)
         {
             adapter.hold();
-            try
-            {
-                Thread.sleep(3000); // Idle for 3 seconds
-            }
-            catch(java.lang.InterruptedException ex)
-            {
-            }
             waitForClosed();
             synchronized(this)
             {
